abacusai.pipeline_step_version — AbacusAI documentation

# `abacusai.pipeline_step_version`

## Module Contents

### Classes

`PipelineStepVersion` | A version of a pipeline step.

class abacusai.pipeline_step_version.PipelineStepVersion(client, stepName=None, pipelineStepVersion=None, pipelineStepId=None, pipelineId=None, pipelineVersion=None, createdAt=None, updatedAt=None, status=None, error=None, outputErrors=None, pythonFunctionId=None, functionVariableMappings=None, stepDependencies=None, outputVariableMappings=None, pipelineStepVersionReferences={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A version of a pipeline step.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - stepName (str) – The name of the step.

    - pipelineStepVersion (str) – The reference to the pipeline step version.

    - pipelineStepId (str) – The reference to this step.

    - pipelineId (str) – The reference to the pipeline this step belongs to.

    - pipelineVersion (str) – The reference to the pipeline version.

    - createdAt (str) – The date and time which this step was created.

    - updatedAt (str) – The date and time when this step was last updated.

    - status (str) – The status of the pipeline version.

    - error (str) – The error message if the pipeline step failed.

    - outputErrors (str) – The error message of a pipeline step’s output.

    - pythonFunctionId (str) – The reference to the python function

    - functionVariableMappings (dict) – The mappings for function parameters’ names.

    - stepDependencies (list[str]) – List of steps this step depends on.

    - outputVariableMappings (dict) – The mappings for the output variables to the step.

    - pipelineStepVersionReferences (PipelineStepVersionReference) – A list to the output instances of the pipeline step version.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

  get_step_version_logs()

    Gets the logs for a given step version.

    Parameters:

      pipeline_step_version (str) – The id of the pipeline step version.

    Returns:

      Object describing the pipeline step logs.

    Return type:

      PipelineStepVersionLogs